import React, { useEffect, useMemo } from 'react';
import { Trans } from '@lingui/macro';
import { IconButton, Typography } from '@mui/material';
import { Flex } from '@shibgreen/core';
import { Route, Routes, useNavigate } from 'react-router-dom';
import IdentitiesPanel from './IdentitiesPanel';
import { LayoutDashboardSub } from '@shibgreen/core';
import ProfileView from './ProfileView';
import ProfileAdd from './ProfileAdd';
import { Add } from '@mui/icons-material';
import { useGetWalletsQuery } from '@shibgreen/api-react';
import { WalletType } from '@shibgreen/api';

export default function SettingsProfiles() {
  const navigate = useNavigate();
  const { data: wallets, isLoading } = useGetWalletsQuery();

  const didList = useMemo(() => {
    let dids = [];
    if (wallets) {
      wallets.forEach((wallet) => {
        if (wallet.type === WalletType.DECENTRALIZED_ID) {
          dids.push(wallet.id);
        }
      });
    }
    return dids;
  }, [wallets]);

  useEffect(() => {
    if (didList.length) {
      navigate(`/dashboard/settings/profiles/${didList[0]}`);
    } else {
      navigate(`/dashboard/settings/profiles/add`);
    }
  }, [didList]);

  function navAdd() {
    navigate(`/dashboard/settings/profiles/add`);
  }

  return (
    <div>
      <Flex flexDirection="row" style={{ width: '350px' }}>
        <Flex flexGrow={1}>
          <Typography variant="h4">
            <Trans>Profiles</Trans>
          </Typography>
        </Flex>
        <Flex alignSelf="end">
          <IconButton onClick={navAdd}>
            <Add />
          </IconButton>
        </Flex>
      </Flex>
      <Routes>
        <Route
          element={<LayoutDashboardSub sidebar={<IdentitiesPanel />} outlet />}
        >
          <Route path=":walletId" element={<ProfileView />} />
          <Route path="add" element={<ProfileAdd />} />
        </Route>
      </Routes>
    </div>
  );
}
